View source: R/BinaryExactCI.R
| BinaryExactCI | R Documentation |
This function calculates the exact confidendence interval for a
response rate presented by n and r.
BinaryExactCI(r, n, alpha = 0.05, drop = TRUE)
r |
Number of success or responder |
n |
Sample size |
alpha |
confidence level |
drop |
Determines if |
Confidence intervals are obtained by a procedure first given in
Clopper and Pearson (1934). This guarantees that the confidence
level is at least (1-\alpha).
Details can be found in the publication listed below.
100 (1-\alpha)\
response rate
clopper1934RBesT
BinaryExactCI(3, 20, 0.05)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.