| asthma | R Documentation |
Data set containing historical information for placebo arms of relevant trials for the treatment of asthma. The primary outcome is the rate of asthma exacerbations, a recurrent event modelled with a negative binomial distribution. The full data set as published in Holzhauer, Wang & Schmidli (2018) summarizes ten historical placebo arms by their back-calculated log mean event rate and dispersion together with the associated standard errors on the log scale.
asthma
A data frame with 10 rows and 11 variables:
study label
ClinicalTrials.gov / ISRCTN registry identifier(s)
follow-up (exposure) duration in years
study size
estimated mean event rate
log mean event rate
standard error of the log mean event rate
estimated dispersion parameter
log dispersion parameter
standard error of the log dispersion parameter
development phase of the trial
holzhauer2018RBesT
## Setting up dummy sampling for fast execution of example
## Please use 4 chains and 20x more warmup & iter in practice
.user_mc_options <- options(RBesT.MC.warmup=50, RBesT.MC.iter=100,
RBesT.MC.chains=2, RBesT.MC.thin=1)
set.seed(34563)
asthma_ph3 <- subset(asthma, phase == "phase III")
map_asthma <- gMAP(cbind(log_mu_hat, se_log_mu_hat) ~ 1 + offset(log(d)) | study,
family = gaussian,
data = asthma_ph3,
tau.dist = "HalfNormal", tau.prior = 0.5,
beta.prior = cbind(0, 2)
)
## Recover user set sampling defaults
options(.user_mc_options)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.