chains2sample: Scrambles the order of a mcmc array object for usage as a...

View source: R/chains2sample.R

chains2sampleR Documentation

Scrambles the order of a mcmc array object for usage as a mcmc sample. It is advisable to set order once per mcmc run, otherwise correlations in the mcmc sample will be lost.

Description

Scrambles the order of a mcmc array object for usage as a mcmc sample. It is advisable to set order once per mcmc run, otherwise correlations in the mcmc sample will be lost.

Usage

chains2sample(chains, order, drop = TRUE)

RBesT documentation built on March 13, 2026, 5:06 p.m.