mixlink: takes x and transforms it according to the defined link...

View source: R/mix.R

mixlinkR Documentation

Description

takes x and transforms it according to the defined link function of the mixture

Usage

mixlink(mix, x)

RBesT documentation built on March 13, 2026, 5:06 p.m.