Learn R Programming

RBesT (version 1.11-0)

BinaryExactCI: Exact Confidence interval for Binary Proportion

Description

This function calculates the exact confidendence interval for a response rate presented by \(n\) and \(r\).

Usage

BinaryExactCI(r, n, alpha = 0.05, drop = TRUE)

Value

100 (1-\(\alpha\))\

response rate

Arguments

r

Number of success or responder

n

Sample size

alpha

confidence level

drop

Determines if drop() will be called on the result

Details

Confidence intervals are obtained by a procedure first given in Clopper and Pearson (1934). This guarantees that the confidence level is at least (1-\(\alpha\)).

Details can be found in the publication listed below.

References

clopper1934RBesT

Examples

Run this code
BinaryExactCI(3, 20, 0.05)

Run the code above in your browser using DataLab