powered by
This function calculates the exact confidendence interval for a response rate presented by \(n\) and \(r\).
BinaryExactCI(r, n, alpha = 0.05, drop = TRUE)
100 (1-\(\alpha\))\
response rate
Number of success or responder
Sample size
confidence level
Determines if drop() will be called on the result
drop()
Confidence intervals are obtained by a procedure first given in Clopper and Pearson (1934). This guarantees that the confidence level is at least (1-\(\alpha\)).
Details can be found in the publication listed below.
clopper1934RBesT
BinaryExactCI(3, 20, 0.05)
Run the code above in your browser using DataLab