| draws-RBesT | R Documentation |
gMAP to draws objectsTransform a gMAP object to a format supported by the
posterior package.
## S3 method for class 'gMAP'
as_draws(x, variable = NULL, regex = FALSE, inc_warmup = FALSE, ...)
## S3 method for class 'gMAP'
as_draws_matrix(x, variable = NULL, regex = FALSE, inc_warmup = FALSE, ...)
## S3 method for class 'gMAP'
as_draws_array(x, variable = NULL, regex = FALSE, inc_warmup = FALSE, ...)
## S3 method for class 'gMAP'
as_draws_df(x, variable = NULL, regex = FALSE, inc_warmup = FALSE, ...)
## S3 method for class 'gMAP'
as_draws_list(x, variable = NULL, regex = FALSE, inc_warmup = FALSE, ...)
## S3 method for class 'gMAP'
as_draws_rvars(x, variable = NULL, regex = FALSE, inc_warmup = FALSE, ...)
x |
A |
variable |
A character vector providing the variables to extract. By default, all variables are extracted. |
regex |
Logical; Should variable be treated as a (vector of)
regular expressions? Any variable in |
inc_warmup |
Should warmup draws be included? Defaults to
|
... |
Arguments passed to individual methods (if applicable). |
To subset iterations, chains, or draws, use the
posterior::subset_draws() method after
transforming the input object to a draws object.
The function is experimental as the set of exported posterior variables are subject to updates.
posterior::draws()
posterior::subset_draws()
## Setting up dummy sampling for fast execution of example
## Please use 4 chains and 20x more warmup & iter in practice
.user_mc_options <- options(RBesT.MC.warmup=50, RBesT.MC.iter=100,
RBesT.MC.chains=2, RBesT.MC.thin=1)
set.seed(34563)
map_AS <- gMAP(cbind(r, n - r) ~ 1 | study,
family = binomial,
data = AS,
tau.dist = "HalfNormal", tau.prior = 1,
beta.prior = 2
)
post_AS <- as_draws(map_AS)
## Recover user set sampling defaults
options(.user_mc_options)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.